==> dolibarr_3.5.8+dfsg1.orig.tar.gz: dolibarr-3.5.8/htdocs/install/mysql/tables/llx_categorie.sql <==
-- ============================================================================
-- Copyright (C) 2005		Brice Davoleau		<e1davole@iu-vannes.fr>
-- Copyright (C) 2005		Matthieu Valleton	<mv@seeschloss.org>
-- Copyright (C) 2005-2012	Regis Houssin		<regis.houssin@capnetworks.com>		
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program. If not, see <http://www.gnu.org/licenses/>.
--
-- ============================================================================

create table llx_categorie
(
	rowid 		    integer AUTO_INCREMENT PRIMARY KEY,
	entity          integer DEFAULT 1 NOT NULL,			-- multi company id
	fk_parent		integer DEFAULT 0 NOT NULL,
	label 		    varchar(255) NOT NULL,				-- category name
	type	        tinyint DEFAULT 1 NOT NULL,			-- category type (product, supplier, customer, member)
	description 	text,								-- description of the category
	fk_soc          integer DEFAULT NULL,				-- attribution of the category has a company (for product only)
	visible         tinyint DEFAULT 1 NOT NULL,			-- determine if the products are visible or not
    import_key      varchar(14)							-- Import key
    
)ENGINE=innodb;

-- 
-- List of codes for the field type
--
-- 0 : product
-- 1 : supplier
-- 2 : customer
--

==> dolibarr_5.0.4+dfsg3.orig.tar.gz: dolibarr-5.0.4/htdocs/install/mysql/tables/llx_categorie.sql <==
-- ============================================================================
-- Copyright (C) 2005		Brice Davoleau		<e1davole@iu-vannes.fr>
-- Copyright (C) 2005		Matthieu Valleton	<mv@seeschloss.org>
-- Copyright (C) 2005-2012	Regis Houssin		<regis.houssin@capnetworks.com>		
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program. If not, see <http://www.gnu.org/licenses/>.
--
-- ============================================================================

create table llx_categorie
(
	rowid 		    integer AUTO_INCREMENT PRIMARY KEY,
	entity          integer DEFAULT 1 NOT NULL,			-- multi company id
	fk_parent		integer DEFAULT 0 NOT NULL,
	label 		    varchar(255) NOT NULL,				-- category name
	type	        tinyint DEFAULT 1 NOT NULL,			-- category type (product, supplier, customer, member)
	description 	text,								-- description of the category
    color           varchar(8),                         -- color
	fk_soc          integer DEFAULT NULL,				-- not used by default. Used when option CATEGORY_ASSIGNED_TO_A_CUSTOMER is set.
	visible         tinyint DEFAULT 1 NOT NULL,			-- determine if the products are visible or not
    import_key      varchar(14)							-- Import key
)ENGINE=innodb;

-- 
-- List of codes for the field type
--
-- 0 : product
-- 1 : supplier
-- 2 : customer
--
